@@ -15,7 +15,6 @@
 import logging
 import logging.handlers
 import os
-import subprocess
 import uuid
 
 import fixtures
@@ -26,6 +25,7 @@ import testtools
 from oslo_rootwrap import cmd
 from oslo_rootwrap import daemon
 from oslo_rootwrap import filters
+from oslo_rootwrap import subprocess
 from oslo_rootwrap import wrapper
 
 
@@ -259,7 +259,7 @@ class RootwrapTestCase(testtools.TestCase):
         with mock.patch('os.readlink') as readlink:
             readlink.return_value = command + ';90bfb2 (deleted)'
             m = mock.mock_open(read_data=command)
-            with mock.patch("__builtin__.open", m, create=True):
+            with mock.patch("six.moves.builtins.open", m, create=True):
                 with mock.patch('os.path.isfile') as exists:
                     def fake_exists(path):
                         return path == command
@@ -421,7 +421,6 @@ class RootwrapTestCase(testtools.TestCase):
             self.assertEqual(c.exec_dirs, [])
 
         self.assertFalse(config.use_syslog)
-        self.assertFalse(config.use_syslog_rfc_format)
         self.assertEqual(config.syslog_log_facility,
                          logging.handlers.SysLogHandler.LOG_SYSLOG)
         self.assertEqual(config.syslog_log_level, logging.ERROR)
@@ -437,12 +436,6 @@ class RootwrapTestCase(testtools.TestCase):
         config = wrapper.RootwrapConfig(raw)
         self.assertTrue(config.use_syslog)
 
-        raw.set('DEFAULT', 'use_syslog_rfc_format', 'oui')
-        self.assertRaises(ValueError, wrapper.RootwrapConfig, raw)
-        raw.set('DEFAULT', 'use_syslog_rfc_format', 'true')
-        config = wrapper.RootwrapConfig(raw)
-        self.assertTrue(config.use_syslog_rfc_format)
-
         raw.set('DEFAULT', 'syslog_log_facility', 'moo')
         self.assertRaises(ValueError, wrapper.RootwrapConfig, raw)
         raw.set('DEFAULT', 'syslog_log_facility', 'local0')
