@@ -18,11 +18,11 @@ import logging.handlers
 import os
 import pwd
 import signal
-import subprocess
 
 from six import moves
 
 from oslo_rootwrap import filters
+from oslo_rootwrap import subprocess
 
 
 class NoFilterMatched(Exception):
@@ -68,9 +68,16 @@ class RootwrapConfig(object):
         # syslog_log_level
         if config.has_option("DEFAULT", "syslog_log_level"):
             v = config.get("DEFAULT", "syslog_log_level")
-            self.syslog_log_level = logging.getLevelName(v.upper())
-            if (self.syslog_log_level == "Level %s" % v.upper()):
-                raise ValueError('Unexpected syslog_log_level: %s' % v)
+            level = v.upper()
+            if (hasattr(logging, '_nameToLevel')
+               and level in logging._nameToLevel):
+                # Workaround a regression of Python 3.4.0 bug fixed in 3.4.2:
+                # http://bugs.python.org/issue22386
+                self.syslog_log_level = logging._nameToLevel[level]
+            else:
+                self.syslog_log_level = logging.getLevelName(level)
+            if (self.syslog_log_level == "Level %s" % level):
+                raise ValueError('Unexpected syslog_log_level: %r' % v)
         else:
             self.syslog_log_level = logging.ERROR
 
@@ -80,13 +87,6 @@ class RootwrapConfig(object):
         else:
             self.use_syslog = False
 
-        # use_syslog_rfc_format
-        if config.has_option("DEFAULT", "use_syslog_rfc_format"):
-            self.use_syslog_rfc_format = config.getboolean(
-                "DEFAULT", "use_syslog_rfc_format")
-        else:
-            self.use_syslog_rfc_format = False
-
 
 def setup_syslog(execname, facility, level):
     rootwrap_logger = logging.getLogger()
